@@ -7,7 +7,7 @@ RDF::Query::Plan - Executable query plan nodes.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan version 2.912.
+This document describes RDF::Query::Plan version 2.913.
 
 =head1 METHODS
 
@@ -66,7 +66,7 @@ use constant CLOSED		=> 0x04;
 
 our ($VERSION, %PLAN_CLASSES);
 BEGIN {
-	$VERSION		= '2.912';
+	$VERSION		= '2.913';
 	%PLAN_CLASSES	= (
 		service	=> 'RDF::Query::Plan::Service',
 	);
@@ -566,7 +566,22 @@ warn Dumper(\@triples); # XXX
 		}
 		
 	} elsif ($type eq 'GroupGraphPattern') {
-		my @patterns	= $algebra->patterns();
+		my @input	= $algebra->patterns();
+		my @patterns;
+		while (my $a = shift(@input)) {
+			if ($a->isa('RDF::Query::Algebra::Service')) {
+				if (scalar(@input) and $input[0]->isa('RDF::Query::Algebra::Service') and $a->endpoint->value eq $input[0]->endpoint->value) {
+					my $b	= shift(@input);
+					if ($a->silent == $b->silent) {
+						my $p	= RDF::Query::Algebra::GroupGraphPattern->new( map { $_->pattern } ($a, $b) );
+						my $s	= RDF::Query::Algebra::Service->new( $a->endpoint, $p, $a->silent );
+						push(@patterns, $s);
+						next;
+					}
+				}
+			}
+			push(@patterns, $a);
+		}
 		
 		my @plans;
 		if (scalar(@patterns) == 0) {
